summaryrefslogtreecommitdiffstats
path: root/kmail/kmheaders.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmheaders.h')
-rw-r--r--kmail/kmheaders.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmail/kmheaders.h b/kmail/kmheaders.h
index 6541d4a99..3dce0a664 100644
--- a/kmail/kmheaders.h
+++ b/kmail/kmheaders.h
@@ -286,12 +286,12 @@ public slots:
virtual void ensureCurrentItemVisible();
/** Select an item and if it is the parent of a closed thread, also
- recursively select its tqchildren. */
+ recursively select its children. */
virtual void setSelected(TQListViewItem *item, bool selected);
/** Select several items by message index
* and if they are the parent of a closed thread, also
* recursively select their tqchildren. */
void setSelectedByIndex(TQValueList<int> items, bool selected);
/** switch a column with the given id (see KPaintInfo enum)
@@ -286,12 +286,12 @@ public slots:
/** Select several items by message index
* and if they are the parent of a closed thread, also
- * recursively select their tqchildren. */
+ * recursively select their children. */
void setSelectedByIndex(TQValueList<int> items, bool selected);
/** switch a column with the given id (see KPaintInfo enum)